package model;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

public class UsuarioDAO {
    public boolean inserir(Usuario u) {
        try {
            String sql = "INSERT INTO usuario (nome, login, senha, PerfilId) "
                    + "VALUES (?,?,?,?)";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setString(1, u.getNome());
            ps.setString(2, u.getLogin());
            ps.setString(3, u.getSenha());
            ps.setInt(4, u.getPerfil().getId());
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("UsuarioDAO::inserir");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public boolean alterar(Usuario u) {
        try {
            String sql = "UPDATE usuario SET nome=?, login=?, senha=?, PerfilId=? "
                    + "WHERE id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setString(1, u.getNome());
            ps.setString(2, u.getLogin());
            ps.setString(3, u.getSenha());
            ps.setInt(4, u.getPerfil().getId());
            ps.setInt(5, u.getId());
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("UsuarioDAO::alterar");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public boolean excluir(int id) {
        try {
            String sql = "DELETE FROM usuario WHERE id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setInt(1, id);
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("UsuarioDAO::excluir");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public Usuario recuperarPorId(int id) {
        try {
            String sql = "SELECT u.id, u.nome Usuario, login, senha, "
                        + "PerfilId, p.nome Perfil "
                        + "FROM usuario u "
                        + "INNER JOIN perfil p ON p.Id = u.PerfilId "
                        + "WHERE u.Id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setInt(1, id);
            ResultSet rs = ps.executeQuery();
            Usuario usuario = null;
            if ( rs.next() ) {
                usuario = new Usuario();
                usuario.setId(rs.getInt("id"));
                usuario.setNome(rs.getString("Usuario"));
                usuario.setSenha(rs.getString("senha"));
                usuario.setLogin(rs.getString("login"));
               
                Perfil p = new Perfil();
                p.setId( rs.getInt("PerfilId") );
                p.setNome( rs.getString("Perfil") );               
                
                usuario.setPerfil(p);
            }
            ps.close();
            con.close();
            return usuario;
        } catch (Exception e) {
            System.out.println("UsuarioDAO::recuperarPorId");
            System.out.println(e.getMessage());
            return null;
        }
    }
    
    public Usuario recuperarPorLogin(String login) {
        try {
            String sql = "SELECT u.id, u.nome Usuario, login, senha, "
                        + "PerfilId, p.nome Perfil "
                        + "FROM usuario u "
                        + "INNER JOIN perfil p ON p.Id = u.PerfilId "
                        + "WHERE u.Login=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setString(1, login);
            ResultSet rs = ps.executeQuery();
            Usuario usuario = null;
            if ( rs.next() ) {
                usuario = new Usuario();
                usuario.setId(rs.getInt("id"));
                usuario.setNome(rs.getString("Usuario"));
                usuario.setSenha(rs.getString("senha"));
                usuario.setLogin(rs.getString("login"));
               
                Perfil p = new Perfil();
                p.setId( rs.getInt("PerfilId") );
                p.setNome( rs.getString("Perfil") );               
                
                usuario.setPerfil(p);
            }
            ps.close();
            con.close();
            return usuario;
        } catch (Exception e) {
            System.out.println("UsuarioDAO::recuperarPorLogin");
            System.out.println(e.getMessage());
            return null;
        }
    }
    
    public List<Usuario> getLista() {
        List<Usuario> lista = new ArrayList<Usuario>();
        try {
            String sql = "SELECT u.id, u.nome Usuario, login, senha, "
                        + "PerfilId, p.nome Perfil "
                        + "FROM usuario u "
                        + "INNER JOIN perfil p ON p.Id = u.PerfilId";
            Connection con = Conexao.conectar();
            Statement st = con.createStatement();
            ResultSet rs = st.executeQuery(sql);
            
            while ( rs.next() ) {
                Usuario usuario = new Usuario();
                usuario.setId(rs.getInt("id"));
                usuario.setNome(rs.getString("Usuario"));
                usuario.setSenha(rs.getString("senha"));
                usuario.setLogin(rs.getString("login"));
               
                Perfil p = new Perfil();
                p.setId( rs.getInt("PerfilId") );
                p.setNome( rs.getString("Perfil") );               
                
                usuario.setPerfil(p);
                
                lista.add(usuario);
            }
            System.out.println("UsuarioDAO::getLista");
            rs.close();
            con.close();
        } catch (Exception e) {
            System.out.println("UsuarioDAO::getLista");
            System.out.println(e.getMessage());
        }
        return lista;
    }
}
